%# BEGIN BPS TAGGED BLOCK {{{
%# 
%# COPYRIGHT:
%# 
%# This software is Copyright (c) 1996-2008 Best Practical Solutions, LLC
%#                                          <jesse@bestpractical.com>
%# 
%# (Except where explicitly superseded by other copyright notices)
%# 
%# 
%# LICENSE:
%# 
%# This work is made available to you under the terms of Version 2 of
%# the GNU General Public License. A copy of that license should have
%# been provided with this software, but in any event can be snarfed
%# from www.gnu.org.
%# 
%# This work is distributed in the hope that it will be useful, but
%# WITHOUT ANY WARRANTY; without even the implied warranty of
%# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%# General Public License for more details.
%# 
%# You should have received a copy of the GNU General Public License
%# along with this program; if not, write to the Free Software
%# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
%# 02110-1301 or visit their web page on the internet at
%# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html.
%# 
%# 
%# CONTRIBUTION SUBMISSION POLICY:
%# 
%# (The following paragraph is not intended to limit the rights granted
%# to you to modify and distribute this software under the terms of
%# the GNU General Public License and is only of importance to you if
%# you choose to contribute your changes and enhancements to the
%# community by submitting them to Best Practical Solutions, LLC.)
%# 
%# By intentionally submitting any modifications, corrections or
%# derivatives to this work, or any other work intended for use with
%# Request Tracker, to Best Practical Solutions, LLC, you confirm that
%# you are the copyright holder for those contributions and you grant
%# Best Practical Solutions,  LLC a nonexclusive, worldwide, irrevocable,
%# royalty-free, perpetual, license to use, copy, create derivative
%# works based on those contributions, and sublicense and distribute
%# those contributions and any derivatives thereof.
%# 
%# END BPS TAGGED BLOCK }}}
<& /Admin/Elements/Header, Title => loc('Select a user') &>
<& /Admin/Elements/UserTabs, current_tab => 'Admin/Users/', 
    current_subtab => 'Admin/Users/',
    Title => loc('Select a user') &>

<h1><% $caption %></h1>
%# $users->BuildSelectQuery

<p><&|/l&>Select a user</&>:</p>
% unless ( $users->Count ) {
<em><&|/l&>No users matching search criteria found.</&></em>
% } else {

<& /Elements/CollectionList,
    OrderBy => 'Name',
    Order => 'ASC',
    Rows  => 100,
    %ARGS,
    Format => $Format,
    Collection => $users,
    AllowSorting => 1,
    PassArguments => [qw(Format Rows Page Order OrderBy UserString UserOp UserField IdLike EmailLike FindDisabledUsers)],
&>

% my $ids = join ',', map $_->id, @{ $users->ItemsArrayRef };
% if ( $ids ) {
<div align="right"><em>
(<a href="<%RT->Config->Get('WebPath')%>/Download/Tabular/User/<% $ids %>/Users.tsv">
<&|/l&>Download as a tab-delimited file</&>
</a>)</em></div>
% }

<br /><br />
% }

<form method="post" action="<% RT->Config->Get('WebPath') %>/Admin/Users/from.html">
% foreach my $field( qw(Format Rows Page Order OrderBy) ) {
%     next unless defined $ARGS{ $field } && length $ARGS{ $field };
<input type="hidden" name="<% $field %>" value="<% $ARGS{ $field } %>" />
% }
%foreach my $str (@UserString){
<input type="hidden" name="UserString" value="<% $str %>" />
%}
<input type="checkbox" class="checkbox" name="FindDisabledUsers" value="1" <% $FindDisabledUsers? 'checked="checked"': '' %> />
<&|/l&>Include disabled users in search.</&>
<br />
<div align="right"><input type="submit" class="button" value="<&|/l&>Go!</&>" /></div> 
</form>

<%INIT>
my $caption;
my $users = RT::Users->new( $session{'CurrentUser'} );
$users->{'find_disabled_rows'} = 1 if $FindDisabledUsers;

$caption = loc("Users matching search criteria");

foreach my $str (@UserString){
  $users->Limit(
    FIELD => 'RealName',
    OPERATOR => 'LIKE',
    VALUE => $str,
    SUBCLAUSE => 'friendly',
  ); 
  $users->Limit(
    FIELD => 'Name',
    OPERATOR => 'LIKE',
    VALUE => $str,
    SUBCLAUSE => 'friendly',
    ENTRYAGGREGATOR => 'OR'
  ); 
}

$Format ||= 
     q{,'<a href="__WebPath__/Admin/Users/Modify.html?id=__id__">__Name__</a>/TITLE:Name'}
    .q{,__RealName__, __EmailAddress__}
    .q{,'<a href="__WebPath__/Search/Results.html?Query=Requestor.id%3D__id__">Requested</a>/TITLE:Tickets'};

if( $RTx::BecomeUser::VERSION &&
    $session{'CurrentUser'}->HasRight(Right => 'SuperUser', Object=>$RT::System) ){   
    $Format .= q{,'<a href="__WebPath__/Admin/Tools/BecomeUser.html?User=__id__">Impersonate</a>/TITLE:BecomeUser'};
}
</%INIT>
<%ARGS>
$Format => undef,

@UserString => (undef)
$UserOp => '='
$UserField => 'Name'
$IdLike => undef
$EmailLike => undef

$FindDisabledUsers => 0
</%ARGS>
